@@ -1,12 +1,13 @@
 """Time utils."""
-import time
 import datetime
+import time
 
 DEFAULT_TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
 
 
 class SECONDS_IN:
     """Units of time."""
+
     MINUTE = 60
     HOUR = 3600
     DAY = 86400
@@ -52,7 +53,7 @@ def format_current_date_with_timezone():
     return '{date} {timezone}'.format(date=date, timezone=timezone)
 
 
-def get_date_id(unixtime):
+def get_date_id(unixtime=None):
     """Get date id."""
     if unixtime is None:
         unixtime = get_unixtime()
